+++
title = "Make the author front-matter plural"
authors = ["Mark Twain", "Arthur Conan Doyle"]
tags = ["front-matter", "keys", "replace", "author"]
draft = false
+++

Some themes might expect the front-matter list variable for authors to
be `authors` instead of the default `author` created by `ox-hugo`.
